@@ -1,12 +1,12 @@
 package NCGI::Cookie;
 use strict;
 use warnings;
-use Carp;
+use Carp qw(croak);
 use Digest::MD5 qw(md5_hex);
 use CGI::Util qw(escape unescape);
 use overload '""' => \&_as_string, 'fallback' => 1;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # ----------------------------------------------------------------------
 # Class Functions
@@ -48,11 +48,12 @@ sub new {
     my $proto = shift;
     my $class = ref($proto) || $proto;
     my $self  = {
-        name    => '',
-        value   => 0,
+        name    => undef,
+        value   => undef,
         expires => 0,
+        max_age => undef,
         path    => '/',
-        domain  => '',
+        domain  => undef,
         @_,
     };
     bless ($self, $class);
@@ -83,15 +84,21 @@ sub expires {
     return $self->{expires};
 }
 
+sub max_age {
+    my $self = shift;
+    $self->{max_age} = _cookie_scrub(shift) if (@_);
+    return $self->{max_age};
+}
+
 sub path {
     my $self = shift;
-    $self->{path} = @_ if (@_);
+    $self->{path} = _cookie_scrub(shift) if (@_);
     return $self->{path};
 }
 
 sub domain {
     my $self = shift;
-    $self->{domain} = @_ if (@_);
+    $self->{domain} = _cookie_scrub(shift) if (@_);
     return $self->{domain};
 }
 
@@ -108,11 +115,18 @@ sub expire_cookie() {
 sub _as_string {
     my $self = shift;
 
+    unless(defined($self->{name}) and defined($self->{value})) {
+        croak('Cookie Name and Value must be defined');
+    }
+
     my $str = $self->{name} .'='. $self->{value}.';';
-    $str   .= ' expires=' . _cookie_date($self->{expires}) . ';' 
-                                                 if ($self->{expires});
-    $str   .= ' path=' . $self->{path} .';'      if ($self->{path});
-    $str   .= ' domain=' . $self->{domain} . ';' if ($self->{domain});
+    $str   .= ' Path=' . $self->{path} .';'      if ($self->{path});
+    $str   .= ' Domain=' . $self->{domain} . ';' if ($self->{domain});
+    $str   .= ' Max-Age=' . $self->{max_age} . ';'
+        if (defined($self->{max_age}));
+    $str   .= ' Expires=' . _cookie_date($self->{expires}) . ';' 
+        if ($self->{expires});
+    $str   .= ' Version=1;';
     return $str;
 }
 
@@ -126,7 +140,7 @@ sub _as_string {
 #
 sub _cookie_scrub {
   my $str = shift;
-  $str =~ s/(\;|\=)//g;
+  $str =~ s/(\;|\=)//g if(defined($str));
   return $str;
 }
 
@@ -137,16 +151,16 @@ sub _cookie_scrub {
 # time is ALWAYS GMT!
 #
 sub _cookie_date() {
-
-  my ($seconds) = @_;
+  my $seconds = shift;
 
   my %mn = ('Jan','01', 'Feb','02', 'Mar','03', 'Apr','04',
             'May','05', 'Jun','06', 'Jul','07', 'Aug','08',
             'Sep','09', 'Oct','10', 'Nov','11', 'Dec','12' );
-  my $sydate=gmtime(time + $seconds);
+
+  my $sydate = gmtime(time + $seconds);
   my ($day, $month, $num, $time, $year) = split(/\s+/,$sydate);
-  my    $zl=length($num);
-  if ($zl == 1) { 
+
+  if (length($num) == 1) { 
     $num = "0$num";
   }
 
@@ -216,6 +230,11 @@ Set or Get the value of the cookie. Will be scrubbed for illegal characters.
 
 Set or Get the expiration value of the cookie in minutes
 
+=head2 max_age
+
+Set or Get the expiration value of the maximum age of the cookie
+in seconds.
+
 =head2 path
 
 Set or Get the path of the cookie
